﻿namespace UltraDataChartPrint
{
    using System;
    using System.Collections.Generic;
    using System.Drawing;
    using System.Drawing.Printing;
    using System.Windows.Forms;

    using Infragistics.Win.DataVisualization;

    public partial class Form1 : Form
    {
        private Random rand = new Random();

        public Form1()
        {
            this.InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.PopulateChartData();
        }

        private void PopulateChartData()
        {
            IList<MyChartData> myChartData = GetMyCharttData(10);

            CategoryXAxis myXAxis = new CategoryXAxis();
            myXAxis.LabelLocation = AxisLabelsLocation.OutsideBottom;
            myXAxis.Label = "Category";
            myXAxis.DataSource = myChartData;


            NumericYAxis myYAxis = new NumericYAxis();
            myYAxis.LabelLocation = AxisLabelsLocation.OutsideLeft;
            myYAxis.Label = "Value";
            myYAxis.MinimumValue = 0.0;

            this.ultraDataChart1.Axes.Add(myXAxis);
            this.ultraDataChart1.Axes.Add(myYAxis);

            ColumnSeries mySeries = new ColumnSeries();
            mySeries.ValueMemberPath = "Value";
            mySeries.Title = "My Chart";
            mySeries.XAxis = myXAxis;
            mySeries.YAxis = myYAxis;
            mySeries.DataSource = myChartData;

            mySeries.TrendLineType = TrendLineType.CubicFit;
            mySeries.TrendLineThickness = 5.0;
            mySeries.TrendLineBrush = new LinearGradientBrush(Color.Red, Color.Red, new System.Drawing.Point(0, 0), new System.Drawing.Point(0, 0));

            mySeries.MarkerType = MarkerType.Automatic;
            mySeries.MarkerOutline = new LinearGradientBrush(Color.Blue, Color.Blue, new System.Drawing.Point(0, 0), new System.Drawing.Point(0, 0));


            this.ultraDataChart1.Series.Add(mySeries);

            this.ultraDataChart1.DefaultInteraction = InteractionState.None;
            this.ultraDataChart1.WindowPositionHorizontal = 0;
            this.ultraDataChart1.WindowPositionVertical = 0;
            this.ultraDataChart1.WindowScaleHorizontal = 1;
            this.ultraDataChart1.WindowScaleVertical = 1;
        }

        private IList<MyChartData> GetMyCharttData(int itemsCount)
        {
            IList<MyChartData> data = new List<MyChartData>();
            for (int item = 0; item < itemsCount; item++)
            {
                data.Add(new MyChartData()
                {
                    Value = rand.Next(1, 10),
                    Category = string.Format("Cat.: {0}", item),
                });
            }

            return data;
        }

        private void ButtonPrint_Click(object sender, EventArgs e)
        {
            PrintDocument printDocument = new PrintDocument();
            PrintDialog prinDialog = new PrintDialog();

            printDocument.PrintPage += new PrintPageEventHandler(this.PrintDocument_PrintPage);
            prinDialog.Document = printDocument;

            if (prinDialog.ShowDialog() == DialogResult.OK)
            {
                printDocument.Print();
            }
        }

        private void PrintDocument_PrintPage(Object sender, PrintPageEventArgs e)
        {
            Bitmap outPutBMP = new Bitmap(this.ultraDataChart1.Width, this.ultraDataChart1.Height);
            System.Drawing.Rectangle outPutRec = new System.Drawing.Rectangle(new System.Drawing.Point(0, 0), this.ultraDataChart1.Size);
            this.ultraDataChart1.DrawToBitmap(outPutBMP, outPutRec);

            //outPutBMP.Save("test.bmp");

            e.Graphics.DrawImage(outPutBMP, outPutRec);

            outPutBMP.Dispose();
        }
    }
}
